from torchsense.models.unet import UNet
from torchsense.models.resnet import resnet50, resnet18, resnet34, resnet101, resnet152
from torchsense.models.gan_g import Generator
from torchsense.models.conv_tasnet import ConvTasNet
